badger\_batcher package
=======================

Subpackages
-----------

.. toctree::

    badger_batcher.utils

Submodules
----------

badger\_batcher.core module
---------------------------

.. automodule:: badger_batcher.core
    :members:
    :undoc-members:
    :show-inheritance:

badger\_batcher.errors module
-----------------------------

.. automodule:: badger_batcher.errors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: badger_batcher
    :members:
    :undoc-members:
    :show-inheritance:
